@@ -7,9 +7,9 @@ def Registry(addremoveedit, regname, value):
 		reg.close
 	if addremoveedit == 'remove':
 		if os.name == 'nt':
-			os.system(f'del /f {value}')
+			os.system(f'del /f {regname}')
 		else:
-			os.system(f'rm sysfiles/registry/{value}')
+			os.system(f'rm sysfiles/registry/{regname}')
 	if addremoveedit == 'edit':
 		print('')
 		editfile = open(regname, 'w')
@@ -34,9 +34,4 @@ def KernelAction(action, two):
 			os.system('shutdown -r -t 0')
 		else:
 			print('Running sudo reboot...')
-			os.system('sudo reboot')
-
-
-cmd = input('Kernel or Registry Tester?> ')
-if cmd == 'Kernel' or 'kernel':
-	
\ No newline at end of file
+			os.system('sudo reboot')
\ No newline at end of file
